<template>
  <el-dialog
    title="退盘"
    :close-on-click-modal="false"
    :visible.sync="visible"
    append-to-body
  >
    <div class="split-task-back-header">
      <div></div>
      <div></div>
    </div>
    <el-table
      class="splitTask-back-table"
      :data="splitTaskBackData"
      style="width: 100%;"
      border
      highlight-current-row
      @row-click="backRowClick"
      stripe
      ref="splitTaskBackTable"
    >
      <el-table-column align="center" width="55" label="单选">
        <template slot-scope="scope">
          <el-checkbox
            class="back-table-single-checkbox"
            v-model="scope.row.commonChecked"
            disabled
          ></el-checkbox>
        </template>
      </el-table-column>
      <el-table-column
        prop="partBatchNo"
        label="SN号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
    </el-table>

    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button type="primary" v-thinclick="`selectBackStock`"
        >确 定</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
export default {
  props: {
    splitTaskBackList: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  components: {},
  data() {
    return {
      visible: false,
      currBackStock: null,
      splitTaskBackData: []
    }
  },
  methods: {
    init() {
      this.visible = true
      this.splitTaskBackData = []
      this.$nextTick(() => {
        this.splitTaskBackList.forEach((item) => {
          this.$set(item, 'commonChecked', false)
          this.splitTaskBackData.push(item)
        })
      })
    },
    splitTaskBackTableHeaderCellStyle({ row, column, rowIndex, columnIndex }) {
      let headerStyle = 'background:#599ef4;color:#fff;'
      if (columnIndex === 0) {
        headerStyle += 'border-radius: 6px 0px 0px 0px;'
      } else if (columnIndex === 7) {
        headerStyle += 'border-radius: 0px 6px 0px 0px;'
      }
      return headerStyle
    },
    splitTaskBackTableRowClassName({ row, rowIndex }) {
      if (rowIndex % 2 === 1) {
        return 'stripe-row'
      } else {
        return ''
      }
    },
    selectBackStock() {
      if (this.currBackStock != null) {
        this.$emit('selectBackStock', this.currBackStock)
        this.visible = false
      } else {
        this.$message.error('请先选择库存零件！')
      }
    },
    backRowClick(row, column) {
      this.splitTaskBackData.forEach((item) => {
        if (row.id !== item.id) {
          item.commonChecked = false
        }
      })
      if (row.commonChecked) {
        row.commonChecked = false
        this.currBackStock = null
        this.$refs.splitTaskBackTable.setCurrentRow()
      } else {
        row.commonChecked = true
        this.currBackStock = row
        this.$refs.splitTaskBackTable.setCurrentRow(row)
      }
    }
  }
}
</script>

<style lang="scss" scoped>
.split-task-back-header {
  margin-top: 10px;
  margin-bottom: 14px;
  display: flex;
  justify-content: space-between;
  align-items: center;
}
.red-but.is-disabled {
  color: #fab6b6;
}

.red-but {
  color: red;
}
.splitTask-back-table >>> .el-table__header th {
  color: #666666;
}

.splitTask-back-table >>> th {
  padding: 3px 0px;
  height: 31px;
}
.splitTask-back-table >>> td {
  padding: 1px 0 0 0;
}
.back-table-single-checkbox
  >>> .el-checkbox__input.is-disabled.is-checked
  .el-checkbox__inner {
  background-color: #006eff;
  border-color: #006eff;
}
.back-table-single-checkbox
  >>> .el-checkbox__input.is-disabled
  .el-checkbox__inner {
  background-color: #ffffff;
  cursor: pointer;
}
.back-table-single-checkbox >>> .el-checkbox__inner::after {
  border: 1px solid #fff !important;
  border-left: 0 !important;
  border-top: 0 !important;
  cursor: pointer !important;
}
</style>
